@@ -2,6 +2,9 @@
 
 void Hostent::destroy()
 {
+    if (h_name = 0)
+        return;
+
     delete h_name;
 
     if (h_aliases)
