@@ -8,7 +8,7 @@ int Randbuffer::underflow()
     ostringstream ostr;
 
     ostr << d_min + 
-            static_cast<int>((d_max - d_min) * rand() / (RAND_MAX + 1.0)) << 
+            static_cast<int>((d_max - d_min) * (rand() / (RAND_MAX + 1.0))) << 
             " ";        
 
     size_t n = ostr.str().length();
